Commands

Enum Commands 

pub enum Commands {
    Sketch {
        input: Vec<PathBuf>,
        output: PathBuf,
        kmer_size: u8,
        fscale: Option<u64>,
        complexity: f64,
        singleton: bool,
        temp_dir: Option<PathBuf>,
        bias_table: Option<PathBuf>,
    },
    Dist {
        input: PathBuf,
        database: PathBuf,
        output: Option<PathBuf>,
        cutoff: f64,
        singleton: bool,
    },
    Bias {
        command: BiasCommands,
    },
    Stats {
        input: PathBuf,
        short: bool,
        full: bool,
    },
}

Variants



Sketch

Sketch one or more files and write the result to an output file

Fields

input: Vec<PathBuf>

Input file(s), directories, or file with list of files to be hashed

output: PathBuf

Output file (.jam format)

kmer_size: u8

K-mer size, all sketches must have the same size to be compared and below 32

fscale: Option<u64>

Scale the hash space to a minimum fraction of the maximum hash value (FracMinHash)

complexity: f64

Complexity cut-off, only hash sequences with complexity above this value This is created via shannon entropy

singleton: bool

Create a separate sketch for each sequence record Will increase the size of the output file

temp_dir: Option<PathBuf>

Custom temporary directory for intermediate files during sorting

bias_table: Option<PathBuf>

Path to a bias table file (.bias) for hash-based filtering



Dist

Estimate containment of a query sequence against a sketch database. Requires all sketches to have the same kmer size

Fields

input: PathBuf

Input FASTA/FASTQ file to query

database: PathBuf

Database sketch (.jam file)

output: Option<PathBuf>

Output to file instead of stdout

cutoff: f64

Cut-off value for similarity/containment

singleton: bool

Singleton mode, process each query sequence separately



Bias

Build and analyze hash bias tables for filtering

Fields



Stats

Display statistics about a JAM database

Fields

input: PathBuf

Input JAM database (.jam file)

short: bool

Short summary only

full: bool

Include the full entry statistics